@@ -1,13 +1,11 @@
-from typing import Dict, List
+from typing import Dict, List, Any
 import numpy as np
 import pandas as pd
 import scipy as sp
-import logging
 import plotly.graph_objects as go
 
 from .alignment_helpers import distance_matrix, backtrack_optimal_path
 from .data_input import dict_to_wide, check_valid_batch_dict
-
 from ..multivariate.methods import MCUVScaler, PCA
 
 epsqrt = np.sqrt(np.finfo(float).eps)
@@ -50,7 +48,9 @@ def determine_scaling(
     collector_mins = []
     for _, batch in batches.items():
         if settings["robust"]:
-            rnge = batch[columns_to_align].quantile(0.98) - batch[columns_to_align].quantile(0.02)
+            rnge = batch[columns_to_align].quantile(0.98) - batch[
+                columns_to_align
+            ].quantile(0.02)
         else:
             rnge = batch[columns_to_align].max() - batch[columns_to_align].min()
 
@@ -99,8 +99,10 @@ def apply_scaling(
         if isinstance(batches, dict):
             batch1 = batches[list(batches.keys())[0]]
             columns_to_align = batch1.columns
-        else:
+        elif isinstance(batches, pd.DataFrame):
             columns_to_align = batches.columns
+        else:
+            assert False, "Undefined input type"
     out = {}
     for batch_id, batch in batches.items():
         out[batch_id] = batch[columns_to_align].copy()
@@ -120,13 +122,17 @@ def reverse_scaling(
     if columns_to_align is None:
         if isinstance(batches, dict):
             columns_to_align = batches[list(batches.keys())[0]].columns
-        else:
+        elif isinstance(batches, pd.DataFrame):
             columns_to_align = batches.columns
+        else:
+            assert False, "Undefined input type"
     out = {}
     for batch_id, batch in batches.items():
         out[batch_id] = batch[columns_to_align].copy()
         for tag, column in out[batch_id].iteritems():
-            out[batch_id][tag] = column * scale_df.loc[tag, "Range"] + scale_df.loc[tag, "Minimum"]
+            out[batch_id][tag] = (
+                column * scale_df.loc[tag, "Range"] + scale_df.loc[tag, "Minimum"]
+            )
     return out
 
 
@@ -234,7 +240,7 @@ def one_iteration_dtw(
     for batch_id, batch in batches_scaled.items():
         try:
             # see Kassidas, page 180
-            batch_subset = batch.iloc[:: settings["subsample"], :]
+            batch_subset = batch.iloc[:: int(settings["subsample"]), :]
             result = dtw_core(batch_subset, refbatch_sc, weight_matrix=weight_matrix)
             average_batch += result.synced
             aligned_batches[batch_id] = result
@@ -311,8 +317,9 @@ def batch_dtw(
         default_settings.update(settings)
     settings = default_settings
     assert settings["maximum_iterations"] >= 3, "At least 3 iterations are required"
-    assert reference_batch in batches, "`reference_batch` was not found in the dict of batches."
-    settings["subsample"] = int(settings["subsample"])
+    assert (
+        reference_batch in batches
+    ), "`reference_batch` was not found in the dict of batches."
 
     assert check_valid_batch_dict(batches, no_nan=True)
 
@@ -351,7 +358,9 @@ def batch_dtw(
         # Deviations from the average batch:
         next_weights = np.zeros((1, refbatch_sc.shape[1]))
         for batch_id, result in aligned_batches.items():
-            next_weights += np.nansum(np.power(result.synced - average_batch, 2), axis=0)
+            next_weights += np.nansum(
+                np.power(result.synced - average_batch, 2), axis=0
+            )
             # TODO: use quadratic weights for now, but try sum of the absolute values instead
             #  np.abs(result.synced - average_batch).sum(axis=0)
 
@@ -364,7 +373,9 @@ def batch_dtw(
             # problematic_threshold = dist_df["Distance"].quantile(0.95)
 
         next_weights = 1.0 / np.where(next_weights > epsqrt, next_weights, 10000)
-        weight_vector = (next_weights / np.sum(next_weights) * len(columns_to_align)).ravel()
+        weight_vector = (
+            next_weights / np.sum(next_weights) * len(columns_to_align)
+        ).ravel()
         # If change in delta_weight is small, we terminate early; no need to fine-tune excessively.
         delta_weight = np.diag(weight_matrix) - weight_vector  # old - new
 
@@ -393,7 +404,10 @@ def batch_dtw(
         "-".join(item)
         for item in zip(
             aligned_wide_df.columns.get_level_values(0),
-            [str(val).zfill(max_places) for val in aligned_wide_df.columns.get_level_values(1)],
+            [
+                str(val).zfill(max_places)
+                for val in aligned_wide_df.columns.get_level_values(1)
+            ],
         )
     ]
     aligned_wide_df.columns = new_labels
@@ -486,20 +500,24 @@ def find_average_length(batches: Dict[str, pd.DataFrame], settings: dict = None)
         default_settings.update(settings)
     settings = default_settings
 
-    batch_lengths = pd.Series({batch_id: df.shape[0] for batch_id, df in batches.items()})
+    batch_lengths = pd.Series(
+        {batch_id: df.shape[0] for batch_id, df in batches.items()}
+    )
     if settings["robust"]:
         # If multiple batches of the median length, return the last one.
         return batch_lengths.index[
             np.where((batch_lengths == batch_lengths.median()).values)[0][-1]
         ]
     else:
-        return batch_lengths.index[(batch_lengths - batch_lengths.mean()).abs().argmin()]
+        return batch_lengths.index[
+            (batch_lengths - batch_lengths.mean()).abs().argmin()
+        ]
 
 
 def find_reference_batch(
     batches: Dict[str, pd.DataFrame],
     columns_to_align: list,
-    settings: dict = None,
+    settings: Dict[str, Any] = None,
 ):
     """
     Find a reference batch. Assumes NO missing data.
@@ -539,7 +557,6 @@ def find_reference_batch(
     if isinstance(settings, dict):
         default_settings.update(settings)
     settings = default_settings
-    settings["subsample"] = int(settings["subsample"])
 
     assert check_valid_batch_dict(batches)
 
